# clinicore: A clinical schema

This schema is focused on the fundamental concepts of clinical data models.

## Contributing

Please run `pre-commit install` and `gitmoji -i` on the CLI before starting to work on this repository!
